@@ -1363,7 +1363,7 @@ impl Time {
             Ok(Self::UtcTime(utc))
         } else if let Some(generalized) = cons
             .take_opt_primitive_if(Tag::GENERALIZED_TIME, |prim| {
-                GeneralizedTime::from_primitive(prim)
+                GeneralizedTime::from_primitive_no_fractional_or_timezone_offsets(prim)
             })?
         {
             Ok(Self::GeneralizedTime(generalized))
@@ -1377,7 +1377,7 @@ impl From<Time> for chrono::DateTime<chrono::Utc> {
     fn from(t: Time) -> Self {
         match t {
             Time::UtcTime(utc) => *utc,
-            Time::GeneralizedTime(gt) => *gt,
+            Time::GeneralizedTime(gt) => gt.into(),
         }
     }
 }
